@@ -1,4 +1,5 @@
 from github import Github
+from github import InputFileContent
 
 def create_repo(repo_name, token=None, provider='github'):
   if not token:
@@ -9,13 +10,13 @@ def create_repo(repo_name, token=None, provider='github'):
     repo = user.create_repo(repo_name, private=True)
     return repo
 
-def create_gist(gist_name, files, token=None, provider='github'):
+def create_gist(gist_name, content, token=None, provider='github'):
   if not token:
     print('Token required')
   if 'github' in provider:
     g = Github(token)
     user = g.get_user()
-    gist = user.create_gist(public=False, files=files)
+    gist = user.create_gist(public=False, files={gist_name: InputFileContent(content)}, description="my description")
     return gist
 
 def delete_repo(repo_name, token=None, provider='github'):
